@@ -14,15 +14,18 @@ ge_tidy <- function(ge, names.commodity, names.agent) {
   names(ge$p) <- names.commodity
   names(ge$z) <- names.agent
 
-  ge$D <- ge$A %*% dg(ge$z)
-  ge$DV <- dg(ge$p) %*% ge$D
+  if (!is.null(ge$A)) {
+    dimnames(ge$A) <- list(names.commodity, names.agent)
+    ge$D <- ge$A %*% dg(ge$z)
+  }
 
+  ge$DV <- dg(ge$p) %*% ge$D
   ge$SV <- dg(ge$p) %*% ge$S
 
-
-  dimnames(ge$A) <- dimnames(ge$S) <- dimnames(ge$SV) <- dimnames(ge$D) <-
+  dimnames(ge$S) <- dimnames(ge$SV) <- dimnames(ge$D) <-
     dimnames(ge$DV) <- list(names.commodity, names.agent)
 
+
   if (!is.null(ge$B)) dimnames(ge$B) <- list(names.commodity, names.agent)
   if (!is.null(ge$S0Exg)) dimnames(ge$S0Exg) <- list(names.commodity, names.agent)
 
